@@ -3,7 +3,7 @@ package PPIx::Regexp::Constant;
 use strict;
 use warnings;
 
-our $VERSION = '0.020';
+our $VERSION = '0.034';
 
 use base qw{ Exporter };
 
@@ -11,6 +11,7 @@ our @EXPORT_OK = qw{
     COOKIE_CLASS
     COOKIE_QUANT
     COOKIE_QUOTE
+    COOKIE_REGEX_SET
     MINIMUM_PERL
     MODIFIER_GROUP_MATCH_SEMANTICS
     RE_CAPTURE_NAME
@@ -22,6 +23,7 @@ our @EXPORT_OK = qw{
 use constant COOKIE_CLASS	=> ']';
 use constant COOKIE_QUANT	=> '}';
 use constant COOKIE_QUOTE	=> '\\E';
+use constant COOKIE_REGEX_SET	=> '])';
 
 use constant MINIMUM_PERL	=> '5.000';
 
@@ -101,10 +103,14 @@ This cookie is set in
 L<PPIx::Regexp::Token::Control|PPIx::Regexp::Token::Control> when a
 C<\Q> is encountered, and it persists until the next C<\E>.
 
+=head2 COOKIE_REGEX_SET
+
+The name of the cookie used to control regular expression sets.
+
 =head2 MINIMUM_PERL
 
 The minimum version of Perl understood by this parser, as a float. It is
-currently set to 5.006, since that is the minimum version of Perl
+currently set to 5.000, since that is the minimum version of Perl
 accessible to the author.
 
 =head2 MODIFIER_GROUP_MATCH_SEMANTICS
@@ -144,7 +150,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2013 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
