@@ -25,10 +25,6 @@ will be the first child.
 This class provides no public methods beyond those provided by its
 superclass.
 
-This class provides the following public methods. Methods not documented
-here are private, and unsupported in the sense that the author reserves
-the right to change or remove them without notice.
-
 =cut
 
 package PPIx::Regexp::Structure::Switch;
@@ -44,23 +40,7 @@ use PPIx::Regexp::Constant qw{
     TOKEN_UNKNOWN
 };
 
-our $VERSION = '0.020';
-
-=begin comment
-
-sub perl_version_introduced {
-    my ( $self ) = @_;
-    my $condition = $self->child( 0 ) or return;
-    $condition->isa( 'PPIx::Regexp::Structure' )
-	and return MINIMUM_PERL;
-    my $content = $condition->content();
-    $content =~ m/ \( \d+ \) /smx and return MINIMUM_PERL;
-    return '5.009005';
-}
-
-=end comment
-
-=cut
+our $VERSION = '0.034';
 
 sub __PPIX_LEXER__finalize {
     my ( $self ) = @_;
@@ -126,7 +106,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2013 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
