@@ -43,7 +43,7 @@ use base qw{ PPIx::Regexp::Token::GroupType };
 
 use PPIx::Regexp::Constant qw{ MINIMUM_PERL };
 
-our $VERSION = '0.020';
+our $VERSION = '0.034';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -57,7 +57,8 @@ our $VERSION = '0.020';
 
     sub perl_version_introduced {
 	my ( $self ) = @_;
-	return $perl_version_introduced{ $self->content() } || '5.005';
+	return $perl_version_introduced{ $self->unescaped_content() } ||
+	    '5.005';
     }
 
 }
@@ -74,6 +75,8 @@ our $VERSION = '0.020';
     }
 }
 
+=begin comment
+
 sub __PPIX_TOKENIZER__regexp {
     my ( $class, $tokenizer, $character ) = @_;
 
@@ -95,6 +98,25 @@ sub __PPIX_TOKENIZER__regexp {
     return;
 }
 
+=end comment
+
+=cut
+
+sub __defining_string {
+    return (
+	{ suffix	=> '{' },
+	'?',
+	'??',
+	'?p',
+    );
+}
+
+sub __match_setup {
+    my ( $class, $tokenizer ) = @_;
+    $tokenizer->expect( qw{ PPIx::Regexp::Token::Code } );
+    return;
+}
+
 1;
 
 __END__
@@ -110,7 +132,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2013 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
