@@ -28,18 +28,18 @@ This class represents modifier characters at the end of the regular
 expression.  For example, in C<qr{foo}smx> this class would represent
 the terminal C<smx>.
 
-=head2 The C<a>, C<d>, C<l>, and C<u> modifiers
+=head2 The C<a>, C<aa>, C<d>, C<l>, and C<u> modifiers
 
-The C<a>, C<d>, C<l>, and C<u> modifiers, introduced into the C<(?...)>
-construction in Perl 5.13.6 (or 5.13.9 in the case of /a) are used to
-force either Unicode pattern semantics (C<u>), locale semantics (C<l>)
-default semantics (C<d> the traditional Perl semantics, which can also
-mean 'dual' since it means Unicode if the string's UTF-8 bit is on, and
-locale if the UTF-8 bit is off), or restricted default semantics (C<a>).
-These are mutually exclusive, and only one can be asserted at a time.
-Asserting any of these overrides the inherited value of any of the
-others. The C<asserted()> method reports as asserted the last one it
-sees, or none of them if it has seen none.
+The C<a>, C<aa>, C<d>, C<l>, and C<u> modifiers, introduced starting in
+Perl 5.13.6, are used to force either Unicode pattern semantics (C<u>),
+locale semantics (C<l>) default semantics (C<d> the traditional Perl
+semantics, which can also mean 'dual' since it means Unicode if the
+string's UTF-8 bit is on, and locale if the UTF-8 bit is off), or
+restricted default semantics (C<a>). These are mutually exclusive, and
+only one can be asserted at a time. Asserting any of these overrides
+the inherited value of any of the others. The C<asserted()> method
+reports as asserted the last one it sees, or none of them if it has seen
+none.
 
 For example, given C<PPIx::Regexp::Token::Modifier> C<$elem>
 representing the invalid regular expression fragment C<(?dul)>,
@@ -52,10 +52,6 @@ If C<$elem> represented regular expression fragment C<(?i)>,
 C<< $elem->asserted( 'd' ) >> would return false, since even though C<d>
 represents the default behavior it is not explicitly asserted.
 
-B<Note> that if this functionality is retracted before Perl 5.14 is
-released, support for it will disappear. See L<PPIx::Regexp/NOTICE> for
-some explanation.
-
 =head2 The caret (C<^>) modifier
 
 Calling C<^> a modifier is a bit of a misnomer. The C<(?^...)>
@@ -92,7 +88,7 @@ use PPIx::Regexp::Constant qw{
     MODIFIER_GROUP_MATCH_SEMANTICS
 };
 
-our $VERSION = '0.020';
+our $VERSION = '0.034';
 
 # Define modifiers that are to be aggregated internally for ease of
 # computation.
@@ -126,9 +122,7 @@ sub asserts {
     my ( $self, $modifier ) = @_;
     $self->{modifiers} ||= $self->_decode();
     if ( defined $modifier ) {
-	my $bin = $aggregate{$modifier}
-	    or return $self->{modifiers}{$modifier};
-	return $self->{modifiers}{$bin} eq $modifier;
+	return __asserts( $self->{modifiers}, $modifier );
     } else {
 	return ( sort grep { defined $_ && $self->{modifiers}{$_} }
 	    map { $de_aggregate{$_} ? $self->{modifiers}{$_} : $_ }
@@ -136,6 +130,13 @@ sub asserts {
     }
 }
 
+sub __asserts {
+    my ( $present, $modifier ) = @_;
+    my $bin = $aggregate{$modifier}
+	or return $present->{$modifier};
+    return defined $present->{$bin} && $modifier eq $present->{$bin};
+}
+
 sub can_be_quantified { return };
 
 =head2 match_semantics
@@ -145,8 +146,8 @@ sub can_be_quantified { return };
  print "This token has $sem match semantics\n";
 
 This method returns the match semantics asserted by the token, as one of
-the letters C<a>, C<d>, C<l>, or C<u>. If no explicit match semantics
-are asserted, this method returns C<undef>.
+the strings C<'a'>, C<'aa'>, C<'d'>, C<'l'>, or C<'u'>. If no explicit
+match semantics are asserted, this method returns C<undef>.
 
 =cut
 
@@ -206,6 +207,12 @@ sub negates {
 }
 
 sub perl_version_introduced {
+    my ( $self ) = @_;
+    return ( $self->{perl_version_introduced} ||=
+	$self->_perl_version_introduced() );
+}
+
+sub _perl_version_introduced {
     my ( $self ) = @_;
     my $content = $self->content();
     my $is_statement_modifier = ( $content !~ m/ \A [(]? [?] /smx );
@@ -235,6 +242,12 @@ sub perl_version_introduced {
 	and not $is_statement_modifier
 	and return '5.013006';
 
+    # The '^' reassert-defaults modifier in embedded modifiers was
+    # introduced in 5.13.6.
+    not $is_statement_modifier
+	and $content =~ m/ \^ /smx
+	and return '5.013006';
+
     $self->asserts( 'r' ) and return '5.013002';
     $self->asserts( 'p' ) and return '5.009005';
     $self->content() =~ m/ \A [(]? [?] .* - /smx
@@ -246,6 +259,43 @@ sub perl_version_introduced {
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
+
+# $present => __aggregate_modifiers( 'modifiers', ... );
+#
+# This subroutine is private to the PPIx::Regexp package. It may change
+# or be retracted without notice. Its purpose is to support defaulted
+# modifiers.
+#
+# Aggregate the given modifiers left-to-right, returning a hash of those
+# present and their values.
+
+sub __aggregate_modifiers {
+    my ( @mods ) = @_;
+    my %present;
+    foreach my $content ( @mods ) {
+	$content =~ s{ [?/]+ }{}smxg;
+	if ( $content =~ m/ \A \^ /smx ) {
+	    @present{ MODIFIER_GROUP_MATCH_SEMANTICS(), qw{ i s m x } }
+		= qw{ d 0 0 0 0 };
+	}
+
+	# Have to do the global match rather than a split, because the
+	# expression modifiers come through here too, and we need to
+	# distinguish between s/.../.../e and s/.../.../ee.
+	my $value = 1;
+	while ( $content =~ m/ ( ( [[:alpha:]-] ) \2* ) /smxg ) {
+	    if ( '-' eq $1 ) {
+		$value = 0;
+	    } elsif ( my $bin = $aggregate{$1} ) {
+		$present{$bin} = $value ? $1 : undef;
+	    } else {
+		$present{$1} = $value;
+	    }
+	}
+    }
+    return \%present;
+}
+
 # This must be implemented by tokens which do not recognize themselves.
 # The return is a list of list references. Each list reference must
 # contain a regular expression that recognizes the token, and optionally
@@ -294,32 +344,7 @@ sub __PPIX_TOKEN__post_make {
     # Decode modifiers from the content of the token.
     sub _decode {
 	my ( $self ) = @_;
-	my $value = 1;
-	my %present;
-	my $content = $self->content();
-	if ( $content =~ m/ \^ /smx ) {
-	    %present = (
-		MODIFIER_GROUP_MATCH_SEMANTICS()	=> 'd',
-		i	=> 0,
-		s	=> 0,
-		m	=> 0,
-		x	=> 0,
-	    );
-	}
-	# Have to do the global match rather than a split, because the
-	# expression modifiers come through here too, and we need to
-	# distinguish between s/.../.../e and s/.../.../ee.
-	while ( $content =~ m/ ( ( [[:alpha:]-] ) \2* ) /smxg ) {
-	    if ( $1 eq '-' ) {
-		$value = 0;
-	    } elsif ( my $bin = $aggregate{$1} ) {
-		$present{$bin} = $1;
-	    } else {
-		$present{$1} = $value;
-	    }
-	}
-
-	return \%present;
+	return __aggregate_modifiers( $self->content() );
     }
 }
 
@@ -338,7 +363,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2013 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
