@@ -40,6 +40,7 @@ use base qw{ PPIx::Regexp::Token };
 use PPIx::Regexp::Constant qw{
     COOKIE_CLASS
     COOKIE_QUANT
+    COOKIE_REGEX_SET
     MINIMUM_PERL
     TOKEN_LITERAL
 };
@@ -52,7 +53,7 @@ use PPIx::Regexp::Token::Backreference	();
 use PPIx::Regexp::Token::Backtrack	();
 use PPIx::Regexp::Token::Recursion	();
 
-our $VERSION = '0.020';
+our $VERSION = '0.034';
 
 # Return true if the token can be quantified, and false otherwise
 
@@ -82,6 +83,7 @@ sub is_quantifier {
 
     my %perl_version_introduced = (
 	qr	=> '5.005',
+	'(?['	=> '5.017008',
     );
 
     sub perl_version_introduced {
@@ -134,6 +136,24 @@ sub is_quantifier {
 		}
 	    }
 
+	    # Modifier changes are local to this parenthesis group
+	    $tokenizer->modifier_duplicate();
+
+	    # The regex-set functionality introduced with 5.17.8 is most
+	    # conveniently handled by treating the initial '(?[' and
+	    # final '])' as ::Structure tokens. Fortunately for us,
+	    # perl5178delta documents that these may not have interior
+	    # spaces.
+
+	    if ( my $accept = $tokenizer->find_regexp(
+		    qr{ \A [(] [?] [[] }smx	# ] ) - help for vim
+		)
+	    ) {
+		$tokenizer->cookie( COOKIE_REGEX_SET, sub { return 1 } );
+		$tokenizer->modifier_modify( x => 1 );	# Implicitly /x
+		return $accept;
+	    }
+
 	    # We expect certain tokens only after a left paren.
 	    $tokenizer->expect(
 		'PPIx::Regexp::Token::GroupType::Modifier',
@@ -145,9 +165,6 @@ sub is_quantifier {
 		'PPIx::Regexp::Token::GroupType::Switch',
 	    );
 
-	    # Modifier changes are local to this parenthesis group
-	    $tokenizer->modifier_duplicate();
-
 	    # Accept the parenthesis.
 	    return 1;
 	}
@@ -257,8 +274,28 @@ sub is_quantifier {
 	# per perlop, the metas outside a [] are {}[]()^$.|*+?\
 	# The difference is that {}[().|*+? are not metas in [], but - is.
 
-	# On encountering our close bracket, we need to delete the cookie.
+	# Close bracket is complicated by the addition of regex sets.
+	# And more complicated by the fact that you can have an
+	# old-style character class inside a regex set. Fortunately they
+	# have not (yet!) permitted nested regex sets.
 	if ( $character eq ']' ) {
+
+	    # If we find '])' and COOKIE_REGEX_SET is present, we have a
+	    # regex set. We need to delete the cookie and accept both
+	    # characters.
+	    if ( ( my $accept = $tokenizer->find_regexp(
+		    # help vim - ( [
+		    qr{ \A []] [)] }smx
+		) )
+		&& $tokenizer->cookie( COOKIE_REGEX_SET )
+
+	    ) {
+		$tokenizer->cookie( COOKIE_REGEX_SET, undef );
+		return $accept;
+	    }
+
+	    # Otherwise we assume we're in a bracketed character class,
+	    # delete the cookie, and accept the close bracket.
 	    $tokenizer->cookie( COOKIE_CLASS, undef );
 	    return 1;
 	}
@@ -292,7 +329,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2013 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
