@@ -19,7 +19,7 @@ C<PPIx::Regexp::Token::Whitespace> has no descendants.
 
 This class represents whitespace. It will appear inside the regular
 expression only if the /x modifier is present, but it may also appear
-between the type and the opening delimiter (e.g. C<qr {foo}> or after
+between the type and the opening delimiter (e.g. C<qr {foo}>) or after
 the regular expression in a bracketed substitution (e.g. C<s{foo}
 {bar}>).
 
@@ -37,7 +37,14 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token };
 
-our $VERSION = '0.020';
+use PPIx::Regexp::Constant qw{ COOKIE_REGEX_SET MINIMUM_PERL };
+
+our $VERSION = '0.034';
+
+sub perl_version_introduced {
+    my ( $self ) = @_;
+    return $self->{perl_version_introduced};
+}
 
 sub significant {
     return;
@@ -48,7 +55,7 @@ sub whitespace {
 }
 
 # Return true if the token can be quantified, and false otherwise
-# sub can_be_quantified { return };
+sub can_be_quantified { return };
 
 # Objects of this class are generated either by the tokenizer itself
 # (when scanning for delimiters) or by PPIx::Regexp::Token::Literal (if
@@ -68,6 +75,20 @@ sub __PPIX_TOKENIZER__regexp {
 
 =cut
 
+sub __PPIX_TOKEN__post_make {
+    my ( $self, $tokenizer, $arg ) = @_;
+
+    if ( ord $self->content() < 128 ) {
+	$self->{perl_version_introduced} = MINIMUM_PERL;
+    } elsif ( $tokenizer && $tokenizer->cookie( COOKIE_REGEX_SET ) ) {
+	$self->{perl_version_introduced} = '5.017008';
+    } else {
+	$self->{perl_version_introduced} = '5.017009';
+    }
+
+    return;
+}
+
 1;
 
 __END__
@@ -83,7 +104,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2013 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
