@@ -42,13 +42,13 @@ use PPIx::Regexp::Token::Whitespace		();
 use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ looks_like_number };
 
-our $VERSION = '0.020';
+our $VERSION = '0.034';
 
 {
     # Names of classes containing tokenization machinery. There are few
     # known ordering requirements, since each class recognizes its own,
     # and I have tried to prevent overlap. Absent such constraints, the
-    # order is in percieved frequency of acceptance, to keep the search
+    # order is in perceived frequency of acceptance, to keep the search
     # as short as possible. If I were conscientious I would gather
     # statistics on this.
     my @classes = (	# TODO make readonly when acceptable way appears
@@ -141,6 +141,13 @@ our $VERSION = '0.020';
 
 	$errstr = undef;
 
+	exists $args{default_modifiers}
+	    and 'ARRAY' ne ref $args{default_modifiers}
+	    and do {
+		$errstr = 'default_modifiers must be an array reference';
+		return;
+	    };
+
 	my $self = {
 	    capture => undef,	# Captures from find_regexp.
 	    content => undef,	# The string we are tokenizing.
@@ -152,6 +159,7 @@ our $VERSION = '0.020';
 	    			# called. Used by get_token to prevent
 				# recursion.
 	    cursor_modifiers => undef,	# Position of modifiers.
+	    default_modifiers => $args{default_modifiers} || [],
 	    delimiter_finish => undef,	# Finishing delimiter of regexp.
 	    delimiter_re =>	undef,	# Recognize finishing delimiter.
 	    delimiter_start => undef,	# Starting delimiter of regexp.
@@ -184,7 +192,11 @@ our $VERSION = '0.020';
 
 	$self->{content} = $self->decode( $self->{content} );
 
-	$self->{cursor_limit} = length $self->{content};
+	if ( $self->{content} =~ m/ \s+ \z /smx ) {
+	    $self->{cursor_limit} = $-[0];
+	} else {
+	    $self->{cursor_limit} = length $self->{content};
+	}
 
 	$self->{trace}
 	    and warn "\ntokenizing '$self->{content}'\n";
@@ -225,6 +237,18 @@ sub cookie {
     }
 }
 
+sub default_modifiers {
+    my ( $self ) = @_;
+    return [ @{ $self->{default_modifiers} } ];
+}
+
+sub __effective_modifiers {
+    my ( $self ) = @_;
+    'HASH' eq ref $self->{effective_modifiers}
+	or return {};
+    return { %{ $self->{effective_modifiers} } };
+}
+
 sub encoding {
     my ( $self ) = @_;
     return $self->{encoding};
@@ -232,6 +256,10 @@ sub encoding {
 
 sub expect {
     my ( $self, @args ) = @_;
+
+    @args
+	or return;
+
     $self->{expect_next} = [
 	map { m/ \A PPIx::Regexp:: /smx ? $_ : 'PPIx::Regexp::' . $_ }
 	@args
@@ -260,7 +288,7 @@ sub find_matching_delimiter {
 
     while ( ++$inx < $self->{cursor_limit} ) {
 	my $char = substr $self->{content}, $inx, 1;
-	if ( $char eq '\\' ) {
+	if ( $char eq '\\' && $finish ne '\\' ) {
 	    ++$inx;
 	} elsif ( $bracketed && $char eq $start ) {
 	    ++$nest;
@@ -310,6 +338,11 @@ sub find_regexp {
     return wantarray ? ( $-[0] + 0, $+[0] + 0 ) : $+[0] + 0;
 }
 
+sub get_start_delimiter {
+    my ( $self ) = @_;
+    return $self->{delimiter_start};
+}
+
 sub get_token {
     my ( $self ) = @_;
 
@@ -353,7 +386,7 @@ sub make_token {
 	and warn "make_token( $length, '$class' ) => '$content'\n";
     $self->{trace} > 1
 	and warn "    make_token: cursor_curr = $self->{cursor_curr}; ",
-    "cursor_limit = $self->{cursor_limit}\n";
+	    "cursor_limit = $self->{cursor_limit}\n";
     my $token = $class->_new( $content ) or return;
     $token->significant() and $self->{expect} = undef;
     $token->__PPIX_TOKEN__post_make( $self, $arg );
@@ -505,32 +538,43 @@ sub __PPIX_TOKENIZER__init {
     my ( $class, $tokenizer, $character ) = @_;
 
     $tokenizer->{mode} = 'kaput';
-    $tokenizer->{content} =~ m/ \A ( qr | m | s )? ( \s* ) ( [^\w\s] ) /smx
+    $tokenizer->{content} =~ m/ \A \s* ( qr | m | s )? ( \s* ) ( [^\w\s] ) /smx
 	or return $tokenizer->make_token(
 	    length( $tokenizer->{content} ), TOKEN_UNKNOWN );
 #   my ( $type, $white, $delim ) = ( $1, $2, $3 );
     my ( $type, $white ) = ( $1, $2 );
+    my $start_pos = defined $-[1] ? $-[1] :
+	defined $-[2] ? $-[2] :
+	defined $-[3] ? $-[3] : 0;
+
     defined $type or $type = '';
     $tokenizer->{type} = $type;
 
     my @tokens;
+    $start_pos
+	and push @tokens, $tokenizer->make_token( $start_pos,
+	'PPIx::Regexp::Token::Whitespace' );
     push @tokens, $tokenizer->make_token( length $type,
 	'PPIx::Regexp::Token::Structure' );
     length $white > 0
 	and push @tokens, $tokenizer->make_token( length $white,
 	'PPIx::Regexp::Token::Whitespace' );
 
-    $tokenizer->{modifiers} = [ {} ];
-    if ( $tokenizer->{content} =~ m/ ( [[:lower:]]* ) \s* \z /smx ) {
-	local $_ = $1;
-	$tokenizer->{cursor_limit} -= length $_;
-	# Can't use a split() here, because we need to distinguish
-	# between s/.../.../e and s/.../.../ee.
-	while ( m/ ( ( . ) \2* ) /smxg ) {
-	    $tokenizer->{modifiers}[0]{$1} = 1;
+    {
+	my @mods = @{ $tokenizer->{default_modifiers} };
+	if ( $tokenizer->{content} =~ m/ ( [[:lower:]]* ) \s* \z /smx ) {
+	    my $mod = $1;
+	    $tokenizer->{cursor_limit} -= length $mod;
+	    push @mods, $mod;
 	}
+	$tokenizer->{effective_modifiers} =
+	    PPIx::Regexp::Token::Modifier::__aggregate_modifiers (
+		@mods );
+	$tokenizer->{modifiers} = [
+	    { %{ $tokenizer->{effective_modifiers} } },
+	];
+	$tokenizer->{cursor_modifiers} = $tokenizer->{cursor_limit};
     }
-    $tokenizer->{cursor_modifiers} = $tokenizer->{cursor_limit};
 
     $tokenizer->{delimiter_start} = substr
 	$tokenizer->{content},
@@ -627,10 +671,22 @@ sub __PPIX_TOKENIZER__finish {
 
 	# We are out of string. Make the modifier token and close up
 	# shop.
-	$tokenizer->{cursor_limit} = length $tokenizer->{content};
+	my $trailer;
+	if ( $tokenizer->{content} =~ m/ \s+ \z /smx ) {
+	    $tokenizer->{cursor_limit} = $-[0];
+	    $trailer = length( $tokenizer->{content} ) -
+		$tokenizer->{cursor_curr};
+	} else {
+	    $tokenizer->{cursor_limit} = length $tokenizer->{content};
+	}
 	push @tokens, $tokenizer->make_token(
 	    $tokenizer->{cursor_limit} - $tokenizer->{cursor_curr},
 	    'PPIx::Regexp::Token::Modifier' );
+	if ( $trailer ) {
+	    $tokenizer->{cursor_limit} = length $tokenizer->{content};
+	    push @tokens, $tokenizer->make_token(
+		$trailer, 'PPIx::Regexp::Token::Whitespace' );
+	}
 	$tokenizer->{mode} = 'kaput';
 
     } else {
@@ -731,6 +787,13 @@ a leading dash. Supported options are:
 
 =over
 
+=item default_modifiers array_reference
+
+This argument specifies default statement modifiers. It is optional, but
+if specified must be an array reference. See the
+L<PPIx::Regexp|PPIx::Regexp> L<new()|PPIx::Regexp/new> documentation for
+the details.
+
 =item encoding name
 
 This option specifies the encoding of the string to be tokenized. If
@@ -763,6 +826,15 @@ This method returns the string being tokenized. This will be the result
 of the L<< PPI::Element->content()|PPI::Element/content >> method if the
 object was instantiated with a L<PPI::Element|PPI::Element>.
 
+=head2 default_modifiers
+
+ print join ', ', @{ $tokenizer->default_modifiers() };
+
+This method returns a reference to a copy of the array passed to the
+C<default_modifiers> argument to L<new()|/new>. If this argument was not
+used to instantiate the object, the return is a reference to an empty
+array.
+
 =head2 encoding
 
 This method returns the encoding of the data being parsed, if one was
@@ -886,6 +958,8 @@ This method inserts a given class at the head of the token scan, for the
 next iteration only. More than one class can be specified. Class names
 can be abbreviated by removing the leading 'PPIx::Regexp::'.
 
+If no class is specified, this method does nothing.
+
 The expectation lasts from the next time L</get_token> is called until
 the next time L<make_token> makes a significant token, or until the next
 C<expect> call if that is done sooner.
@@ -925,6 +999,13 @@ This method returns the offset from the current position in the content
 string to the matching delimiter (which will always be positive), or
 undef if no match can be found.
 
+=head2 get_start_delimiter
+
+ my $start_delimiter = $tokenizer->get_start_delimiter();
+
+This method is used by tokenizers to access the start delimiter for the
+regular expression.
+
 =head2 get_token
 
  my $token = $tokenizer->make_token( 3 );
@@ -1063,7 +1144,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2011 by Thomas R. Wyant, III
+Copyright (C) 2009-2013 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
